;; This file holds site initializations.

(custom-set-default! 'custom-activate-default-im-name? #t)
(custom-set-default! 'custom-preserved-default-im-name 'anthy)
(define default-im-name 'anthy)

(define uim-color-custom
  '((reversed-preedit-foreground . "black")
    (reversed-preedit-background . "#d0ffff")
    (separator-foreground . "gray60")
    (separator-background . "")
    (reversed-separator-foreground . "gray60")
    (reversed-separator-background . "#d0ffff")))

(let ((str (apply string-append (mapcar ucs-to-utf8-string
					'(12459 12473 12479 12512)))))
  (custom-choice-list-append!
   'uim-color (list 'uim-color-custom str str)))

(custom-set-default! 'uim-color 'uim-color-custom)

(custom-set-default-key! 'generic-on-key
			 '("zenkaku-hankaku" "Kanji"
			   "<Shift> " "<IgnoreShift><Control>\\"))
(custom-set-default-key! 'generic-off-key
			 '("zenkaku-hankaku" "Kanji"
			   "<Shift> " "<IgnoreShift><Control>\\"))
(custom-set-default-key! 'generic-begin-conv-key '(" " "Henkan_Mode"))
(custom-set-default-key! 'generic-next-candidate-key
			 '(" " "Henkan_Mode" "down" "<IgnoreCase><Control>n"))
(custom-set-default-key! 'generic-prev-candidate-key
			 '("<Shift>Henkan_Mode" "up" "<IgnoreCase><Control>p"))
